@@ -268,13 +268,17 @@ class SlamMetaData(CalibratedSceneMetaData):
                  time_specification: TimeSpecification,
                  source_specification: SourceSpecification,
                  calibration_id: int,
-                 sequence_id: int):
+                 sequence_id: int,
+                 sub_sequence_id: int,
+                 settings: dict = None):
         super().__init__(external_id, source_specification, calibration_id)
         self.vehicle_data = vehicle_data
         self.dynamic_objects = dynamic_objects
         self.trajectory = trajectory
         self.time_specification = time_specification
         self.sequence_id = sequence_id
+        self.sub_sequence_id = sub_sequence_id
+        self.settings = settings
 
     def to_dict(self):
         as_dict = super().to_dict()
@@ -282,6 +286,10 @@ class SlamMetaData(CalibratedSceneMetaData):
         as_dict["dynamicObjects"] = self.dynamic_objects
         as_dict["timeSpecification"] = self.time_specification.to_dict()
         as_dict["sequenceId"] = self.sequence_id
+        as_dict["subSequenceId"] = self.sub_sequence_id
+        
+        if self.settings:
+            as_dict["settings"] = self.settings
 
         if self.trajectory:
             as_dict["trajectory"] = self.trajectory
@@ -314,14 +322,16 @@ class FilesToUpload(RequestCall):
 
 
 class PoseTransform(RequestCall):
-    def __init__(self, timestamp: float, position: List[float], rotation_quaternion: List[float]):
+    def __init__(self, timestamp: int, utc_timestamp: float, position: List[float], rotation_quaternion: List[float]):
         self.timestamp = timestamp
+        self.utc_timestamp = utc_timestamp
         self.position = position
         self.rotation_quaternion = rotation_quaternion
 
     def to_dict(self):
         return {
             "timestamp": self.timestamp,
+            "utc_timestamp": self.utc_timestamp,
             "position": self.position,
             "rotation_quaternion": self.rotation_quaternion
         }
